#!/usr/bin/python
# encoding=utf-8

""" Can only be modified by the administrator. Only fixtures are provided.
"""

from tep.fixture import *


@pytest.fixture
def common_created_by_admin():
    pass
